@@ -1,6 +1,6 @@
 /*
  * wpa_supplicant - Internal definitions
- * Copyright (c) 2003-2006, Jouni Malinen <jkmaline@cc.hut.fi>
+ * Copyright (c) 2003-2006, Jouni Malinen <j@w1.fi>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
@@ -158,9 +158,9 @@ struct wpa_params {
 	int dbus_ctrl_interface;
 
 	/**
-	 * wpa_debug_use_file - Write debug to a file (instead of stdout)
+	 * wpa_debug_file_path - Path of debug file or %NULL to use stdout
 	 */
-	int wpa_debug_use_file;
+	const char *wpa_debug_file_path;
 };
 
 /**
@@ -199,16 +199,16 @@ struct wpa_client_mlme {
 
 	int auth_tries, assoc_tries;
 
-	int ssid_set:1;
-	int bssid_set:1;
-	int prev_bssid_set:1;
-	int authenticated:1;
-	int associated:1;
-	int probereq_poll:1;
-	int use_protection:1;
-	int create_ibss:1;
-	int mixed_cell:1;
-	int wmm_enabled:1;
+	unsigned int ssid_set:1;
+	unsigned int bssid_set:1;
+	unsigned int prev_bssid_set:1;
+	unsigned int authenticated:1;
+	unsigned int associated:1;
+	unsigned int probereq_poll:1;
+	unsigned int use_protection:1;
+	unsigned int create_ibss:1;
+	unsigned int mixed_cell:1;
+	unsigned int wmm_enabled:1;
 
 	struct os_time last_probe;
 
@@ -395,6 +395,8 @@ void wpa_supplicant_deinit(struct wpa_global *global);
 int wpa_supplicant_scard_init(struct wpa_supplicant *wpa_s,
 			      struct wpa_ssid *ssid);
 
+/* events.c */
+void wpa_supplicant_mark_disassoc(struct wpa_supplicant *wpa_s);
 
 /* driver_ops */
 static inline void * wpa_drv_init(struct wpa_supplicant *wpa_s,
